import matplotlib.pyplot as plt
import numpy as np
import pandas as pd
import sys


def moving_average(data, window=30):
    return np.convolve(data, np.ones(window) / window, 'same')[window:]


if __name__ == "__main__":
    if len(sys.argv) != 6:
        print "USAGE:", sys.argv[0], "data_file outpath window_size demo fill"
        sys.exit(1)

    data_file, outpath, window_size, demo, fillData = sys.argv[1:]
    window_size = int(window_size)
    fillData = eval("bool(" + fillData + ")")

    data = pd.read_csv(data_file, index_col=0, comment='#')

    if fillData:
        time_start, time_end = data.index[0], data.index[-1] + 1
        timestamps = np.arange(time_start, time_end)

        data = data.reindex(index=timestamps, method="nearest")

    start_time = data.iloc[0].name
    data.index = data.index - start_time

    fig = plt.figure(figsize=(20, 6))
    plt.ylim(0, 1023)
    plt.xlim(0, len(data[demo]))
    plt.plot(data.index, data[demo])

    result = pd.DataFrame()
    for col in data.columns:
        result[col] = moving_average(data[col], window_size)

    result.index = data.index[window_size:]
    plt.plot(result.index, result[demo])
    plt.xticks(data.index[::600], data.index[::600] / 60)

    savename = outpath + '/low_pass_' + demo + '.png'
    fig.savefig(savename, bbox_inches='tight')
    plt.close(fig)

    result.index = result.index + start_time
    result.to_csv(outpath + "/low_pass.csv")
