import matplotlib.pyplot as plt
import numpy as np
import pandas as pd
import sys


def subsample(arr, sample_len):
    result = []

    for n in xrange(0, len(arr), sample_len/2):
        result = np.append(result, np.mean(arr[n:n+sample_len]))

    return result


if __name__ == "__main__":
    if len(sys.argv) != 5:
        print "USAGE:", sys.argv[0], "data_file outpath window_size demo"
        sys.exit(1)

    data_file, outpath, window_size, demo = sys.argv[1:]
    window_size = int(window_size)

    data = pd.read_csv(data_file, index_col=0, comment='#')
    result = pd.DataFrame()
    result_index = data.iloc[::(window_size/2), :].index

    iai = pd.DataFrame()

    for col in data.columns:
        result[col] = subsample(data[col], window_size)
        iai[col] = [np.sum(result[col])]

    index = np.arange(0, len(result[demo]))

    fig = plt.figure(figsize=(20, 6))
    plt.xlim(0, len(result[demo]))
    plt.plot(result[demo])

    figindex = np.arange(0, len(result[demo]))
    delta = int(600 / window_size * 2)
    figticks = (result_index[::delta] - result_index[0]) / 60
    plt.xticks(figindex[::delta], figticks)

    savename = outpath + '/subsampled_' + demo + '.png'
    fig.savefig(savename, bbox_inches='tight')
    plt.close(fig)

    result.index = result_index
    result.to_csv(outpath + "/subsampled.csv")
    iai.to_csv(outpath + "/individual_affective_intensity.csv")
